Skip to main contentModule assertion
Source - BinaryAssertion
- An assertion about two objects
lhs and rhs. - CollectedAssertion
- A group of assertions, where the first one to fail will short-circuit.
- Fail
- An assertion that will unconditionally fail.
- MultiAssertion
- A group of assertions, all tested simultaneously.
- MultiDynAssertion
- A group of assertions, possibly of different types, all tested simultaneously.
- ShouldFail
- An assertion that will fail if the given assertion was true
and succeed if the given assertion was false.
- Succeed
- An assertion that will unconditionally succeed.
- UnaryAssertion
- An assertion about an object
this.
- AssertAll
- Extension trait, blanked implemented for
Iterators of Assertions. - Assertion
- An assertion that has been made about some object.