Module assertion

Module assertion 

Structs

BinaryAssertion
An assertion about two objects lhs and rhs.
Fail
An assertion that will unconditionally fail.
MultiAssertion
A group of assertions, all tested simultaneously.
MultiDynAssertion
A group of assertions, possibly of different types, all tested simultaneously.
ShouldFail
An assertion that will fail if the given assertion was true and succeed if the given assertion was false.
Succeed
An assertion that will unconditionally succeed.
UnaryAssertion
An assertion about an object this.

Traits

Assertion
An assertion that has been made about some object.