Assert

Struct Assert 

pub struct Assert<T> { /* private fields */ }
A wrapper around some object that can be reasoned about.

Use assert_that! to construct an Assert and then use methods to make some Assertion. Assertions can be returned from tests and verified by the test framework.

Implementations

Source

impl<T> Assert<T>

pub const fn as_ref(&self) -> Assert<&T>

Converts from &Assert<T> to Assert<&T>.

pub fn as_deref<U>(&self) -> Assert<&U>
where T: Deref<Target = U>,

Converts from Assert<T> or &Assert<T> to Assert<&T::Target> via Deref.

pub fn map<F, U>(self, f: F) -> Assert<U>
where F: FnOnce(T) -> U,

Maps an Assert<T> to an Assert<U> by applying a function to its contained value.

pub fn is_equal_to<U>(self, other: U) -> BinaryAssertion<T, U>
where T: PartialEq<U> + Debug, U: Debug,

Assert that self is equal to other.

pub fn is_not_equal_to<U>(self, other: U) -> BinaryAssertion<T, U>
where T: PartialEq<U> + Debug, U: Debug,

Assert that self is not equal to other.

pub fn is_greater_than<U>(self, other: U) -> BinaryAssertion<T, U>
where T: PartialOrd<U> + Debug, U: Debug,

Assert that self is greater than other.

pub fn is_less_than<U>(self, other: U) -> BinaryAssertion<T, U>
where T: PartialOrd<U> + Debug, U: Debug,

Assert that self is less than other.

pub fn is_greater_than_or_equal_to<U>(self, other: U) -> BinaryAssertion<T, U>
where T: PartialOrd<U> + Debug, U: Debug,

Assert that self is greater than or equal to other.

pub fn is_less_than_or_equal_to<U>(self, other: U) -> BinaryAssertion<T, U>
where T: PartialOrd<U> + Debug, U: Debug,

Assert that self is less than or equal to other.

pub fn is_in(self, container: &[T]) -> BinaryAssertion<&[T], T>
where T: PartialEq,

Assert that self is contained by other.

pub fn is_not_in(self, container: &[T]) -> BinaryAssertion<&[T], T>
where T: PartialEq,

Assert that self is not contained by other.

Source

impl<T> Assert<&T>

pub fn cloned(self) -> Assert<T>
where T: Clone,

Maps an Assert<&T> to Assert<T> by cloning the contained value.

pub const fn copied(self) -> Assert<T>
where T: Copy,

Maps an Assert<&T> to Assert<T> by copying the contained value.

Source

impl Assert<bool>

pub const fn is_true(self) -> UnaryAssertion<bool>

Assert that self is true.

pub const fn is_false(self) -> UnaryAssertion<bool>

Assert that self is false.

Source

impl<T: Debug> Assert<Option<T>>

pub fn is_some(self) -> UnaryAssertion<Option<T>>

Assert that self is Some.

pub fn is_none(self) -> UnaryAssertion<Option<T>>

Assert that self is None.

pub fn is_some_and<F, A>(self, f: F) -> UnaryAssertion<Option<T>>
where F: Fn(Assert<&T>) -> A, A: Assertion,

Assert that self is Some and the Some value matches a predicate.

pub fn is_none_or<F, A>(self, f: F) -> UnaryAssertion<Option<T>>
where F: Fn(Assert<&T>) -> A, A: Assertion,

Assert that self is None or the Some value matches a predicate.

Source

impl<T: Debug, E: Debug> Assert<Result<T, E>>

pub fn is_ok(self) -> UnaryAssertion<Result<T, E>>

Assert that self is Ok.

pub fn is_err(self) -> UnaryAssertion<Result<T, E>>

Assert that self is Err.

pub fn is_ok_and<F, A>(self, f: F) -> impl Assertion
where F: Fn(Assert<&T>) -> A, A: Assertion,

Assert that self is Ok and the Ok value matches a predicate.

pub fn is_err_and<F, A>(self, f: F) -> UnaryAssertion<Result<T, E>>
where F: Fn(Assert<&E>) -> A, A: Assertion,

Assert that self is Err and the Err value matches a predicate.

Source

impl<'a, T> Assert<&'a [T]>

pub fn is_sorted(self) -> UnaryAssertion<&'a [T]>
where T: PartialOrd,

Assert that self is sorted according to PartialOrd::partial_cmp.

pub fn is_not_sorted(self) -> UnaryAssertion<&'a [T]>
where T: PartialOrd,

Assert that self is not sorted according to PartialOrd::partial_cmp.

pub fn is_sorted_by<'b, F>(self, compare: F) -> UnaryAssertion<&'a [T]>
where F: FnMut(&'b T, &'b T) -> bool, 'a: 'b,

Assert that self is sorted according to the provided comparison function.

pub fn is_not_sorted_by<'b, F>(self, compare: F) -> UnaryAssertion<&'a [T]>
where F: FnMut(&'b T, &'b T) -> bool, 'a: 'b,

Assert that self is not sorted according to the provided comparison function.

pub fn is_sorted_by_key<'b, F, K>(self, f: F) -> UnaryAssertion<&'a [T]>
where F: FnMut(&'b T) -> K, K: PartialOrd, 'a: 'b,

Assert that self is sorted according to the provided key extraction function.

pub fn is_not_sorted_by_key<'b, F, K>(self, f: F) -> UnaryAssertion<&'a [T]>
where F: FnMut(&'b T) -> K, K: PartialOrd, 'a: 'b,

Assert that self is not sorted according to the provided key extraction function.

pub const fn is_empty(self) -> UnaryAssertion<&'a [T]>

Assert that self is empty.

pub const fn is_not_empty(self) -> UnaryAssertion<&'a [T]>

Assert that self is not empty.

pub const fn is_len(self, len: usize) -> BinaryAssertion<&'a [T], usize>

Assert that self has the given length.

pub const fn is_not_len(self, len: usize) -> BinaryAssertion<&'a [T], usize>

Assert that self does not have the given length.

pub fn contains(self, elem: T) -> BinaryAssertion<&'a [T], T>
where T: PartialEq,

Assert that self contains elem.

pub fn does_not_contain(self, elem: T) -> BinaryAssertion<&'a [T], T>
where T: PartialEq,

Assert that self does not contain elem.